Load and disply simple SVG files in Bevy.
This crate provides a Bevy Plugin to easily load and display a simple SVG file.
Usage
Simply add the crate in your Cargo.toml and add the plugin to your app
App::new()
.add_plugin(bevy_svg::prelude::SvgPlugin)
.run();Modules
- prelude
- Import this module as
use bevy_svg::prelude::*to get convenient imports.
Structs
- SvgPlugin
- A plugin that provides resources and a system to draw
Svgs. - SvgSet
- Set in which
Svgs get drawn.
Traits
- Convert
- A locally defined
std::convert::Intosurrogate to overcome orphan rules.